@@ -247,32 +247,8 @@
 
     function updateFilterControls(page) {
 
-        var query = getQuery(page);
-        $('.alphabetPicker', page).alphaValue(query.NameStartsWithOrGreater);
     }
 
-    pageIdOn('pageinit', "channelItemsPage", function () {
-
-        var page = this;
-
-        $('.alphabetPicker', this).on('alphaselect', function (e, character) {
-
-            var query = getQuery(page);
-            query.NameStartsWithOrGreater = character;
-            query.StartIndex = 0;
-
-            reloadItems(page);
-
-        }).on('alphaclear', function (e) {
-
-            var query = getQuery(page);
-            query.NameStartsWithOrGreater = '';
-
-            reloadItems(page);
-        });
-
-    });
-
     pageIdOn('pagebeforeshow', "channelItemsPage", function () {
 
         var page = this;
